@@ -59,7 +59,7 @@ class Sphinx(Builder):
     def _get_source_folder_targets(self) -> List[str]:
         return [
             os.path.join(self.source_folder, "modules.rst"),
-            os.path.join(self.source_folder, "{}.rst".format(self.package_name)),
+            os.path.join(self.source_folder, f"{self.package_name}.rst"),
             # We need to add the list of all output files of running sphinx-apidoc
             # os.path.join(self.source_folder, "{}.endpoints.rst".format(self.package_name)),
         ]
